@@ -6,6 +6,7 @@ from scipy.spatial.distance import pdist
 
 from .Variogram import Variogram
 from skgstat import plotting
+from .MetricSpace import MetricSpace, MetricSpacePair
 
 
 class DirectionalVariogram(Variogram):
@@ -227,8 +228,17 @@ class DirectionalVariogram(Variogram):
 
         self._direction_mask_cache = None
 
+        if not isinstance(coordinates, MetricSpace):
+            coordinates = np.asarray(coordinates)
+            coordinates = MetricSpace(coordinates.copy(), dist_func)
+            # FIXME: Currently _direction_mask / _angles / _euclidean_dist don't get correctly calculated for sparse dspaces
+            #coordinates = MetricSpace(coordinates.copy(), dist_func, maxlag if maxlag and not isinstance(maxlag, str) and maxlag >= 1 else None)
+        else:
+            assert self.dist_func == coordinates.dist_metric, "Distance metric of variogram differs from distance metric of coordinates"
+            assert coordinates.max_dist is None
+            
         # Set coordinates
-        self._X = np.asarray(coordinates)
+        self._X = coordinates
 
         # pairwise difference
         self._diff = None
@@ -310,7 +320,6 @@ class DirectionalVariogram(Variogram):
         self.fit(force=True)
 
     def preprocessing(self, force=False):
-        self._calc_distances(force=force)
         self._calc_direction_mask_data(force)
         self._calc_diff(force=force)
         self._calc_groups(force=force)
@@ -344,24 +353,28 @@ class DirectionalVariogram(Variogram):
         `azimuth <skgstat.DirectionalVariogram.azimuth>`_
 
         """
+
+        # FIXME: This should be optimized for the sparse case (range << bbox(coordinates)),
+        # i.e. use the MetricSpace in self._X
+        
         # check if already calculated
         if self._angles is not None and not force:
             return
 
-        # if self._X is of just one dimension, concat zeros.
-        if self._X.ndim == 1:
-            _x = np.vstack(zip(self._X, np.zeros(len(self._X))))
-        elif self._X.ndim == 2:
-            _x = self._X
+        # if self.coordinates is of just one dimension, concat zeros.
+        if self.coordinates.ndim == 1:
+            _x = np.vstack(zip(self.coordinates, np.zeros(len(self.coordinates))))
+        elif self.coordinates.ndim == 2:
+            _x = self.coordinates
         else:
             raise NotImplementedError('N-dimensional coordinates cannot be handled')
 
         # for angles, we need Euklidean distance,
         # no matter which distance function is used
-        if self._dist_func_name == "euclidean":
-            self._euclidean_dist = self._dist
-        else:
-            self._euclidean_dist = pdist(_x, "euclidean")
+        #if self._dist_func_name == "euclidean":
+        #    self._euclidean_dist = scipy.spatial.distance.squareform(self.distance_matrix)
+        #else:
+        self._euclidean_dist = pdist(_x, "euclidean")
 
         # Calculate the angles
         # (a - b).[1,0] = ||a - b|| * ||[1,0]|| * cos(v)
@@ -557,6 +570,11 @@ class DirectionalVariogram(Variogram):
 
         return self._bins.copy()
 
+    def to_gstools(self, *args, **kwargs):
+        raise NotImplementedError(
+            "Exporting DirectinalVariogram is currently not supported."
+        )
+
     def _calc_groups(self, force=False):
         super(DirectionalVariogram, self)._calc_groups(force=force)
 
